model EnzymeCatalysis "Model shows a standard enzyme reaction"
  extends BioChem.Compartments.ConstantCompartment(V.fixed = true);
  BioChem.Substances.Substance enzyme "The enzyme provide a lower energy reaction path for the reaction by stabilizing the transition state, greatly increasing the reaction rate." annotation(Placement(visible = true, transformation(origin = {0, 25}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance substrate(c.start = Sc0, c.fixed = true) "Defined as a reactant that is consumed in a enzymatic (or catalytic) reaction." annotation(Placement(visible = true, transformation(origin = {-60, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Reactions.MassAction.Reversible.BiUni.Bur bur(k1 = kOn, k2 = kOff) "The reversible, first reaction in the short reaction chain from substrate to product." annotation(Placement(visible = true, transformation(origin = {-30, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance ES_complex "The enzyme-substrate complex. The enzyme reversibly binds the substrate, stabilizing its transition state." annotation(Placement(visible = true, transformation(origin = {0, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Substances.Substance product(c.start = 0, c.fixed = true) "The resulting substance of the reaction." annotation(Placement(visible = true, transformation(origin = {60, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  BioChem.Reactions.MassAction.Irreversible.UniBi.Ubi ubi(k1 = kCat) "The second reaction in the short reaction chain from substrate into product." annotation(Placement(visible = true, transformation(origin = {30, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  parameter BioChem.Units.ReactionCoefficient kOn = 1000 "Association coefficient for enzyme-substrate binding reaction (L/(mol·s))";
  parameter BioChem.Units.ReactionCoefficient kOff = 1 "Disassociation coefficient for enzyme-substrate binding reaction (1/s)";
  parameter BioChem.Units.ReactionCoefficient kCat = 100 "Reaction rate coefficient for enzyme reaction (1/s)";
  BioChem.Reactions.MassAction.Irreversible.UniUni.Uui uui(k1 = 0.00001) "The non-catalyzed reaction, with a rate several thousand times slower than the enzymatic reaction." annotation(Placement(visible = true, transformation(origin = {0, -20}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  parameter BioChem.Units.Concentration Sc0 = 0.01 "Initial concentration of substrate" annotation(Dialog(group = "Initialization"));
  parameter BioChem.Units.Concentration Pc0 = 0 "Initial concentration of product" annotation(Dialog(group = "Initialization"));
  parameter BioChem.Units.Concentration Ec0 = 0.0001 "Initial concentration of enzymes" annotation(Dialog(group = "Initialization"));
  encapsulated type Init = enumeration(NoInit "No initialization (start values are used as guess values with fixed=false)", SteadyState "Steady state initialization", Zero "Initialization with 0 enzyme complex concentration") "Enumeration defining initialization of the enzyme complex" annotation(Evaluate = true, Documentation(info = "<html>
     <p>The following initialization alternatives are available:</p>
     <dl>
       <dt><code><strong>NoInit</strong></code></dt>
         <dd>No initialization (start values are used as guess values with <code>fixed=false</code>)</dd>
       <dt><code><strong>SteadyState</strong></code></dt>
         <dd>Steady state initialization (derivatives of states are zero)</dd>
       <dt><code><strong>InitialState</strong></code></dt>
         <dd>Initialization with initial states</dd>
       <dt><code><strong>InitialOutput</strong></code></dt>
         <dd>Initialization with initial outputs (and steady state of the states if possible)</dd>
     </dl>
   </html>"), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {56, 56, 56}, fillColor = {192, 192, 192}, fillPattern = FillPattern.Solid, extent = {{-100, -100}, {100, 100}}), Text(visible = true, textColor = {0, 114, 195}, extent = {{-90, -50}, {90, 50}}, textString = "1..n")}));
  parameter Init enzymeInitialization = Init.Zero "Initialization options for the enzyme reaction, see documentation" annotation(Dialog(group = "Initialization"));
initial equation
  if enzymeInitialization == Init.SteadyState then
    ubi.rr = bur.rr;
    enzyme.c + ES_complex.c = Ec0;
  elseif enzymeInitialization == Init.Zero then
    ES_complex.c = 0;
    enzyme.c = Ec0;
  end if;
equation
  connect(enzyme.n1, bur.s1) annotation(Line(visible = true, origin = {-32.438, 15}, points = {{32.438, 10}, {7.438, 10}, {-17.562, 10}, {-17.562, -10}, {-8.812, -10}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(substrate.n1, bur.s2) annotation(Line(visible = true, origin = {-48.875, -3.75}, points = {{-11.125, -16.25}, {-11.125, -1.25}, {3.875, -1.25}, {7.625, -1.25}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(bur.p1, ES_complex.n1) annotation(Line(visible = true, origin = {-9.375, 0}, points = {{-9.375, 0}, {9.375, 0}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(ES_complex.n1, ubi.s1) annotation(Line(visible = true, origin = {9.375, 0}, points = {{-9.375, 0}, {9.375, -0}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(ubi.p2, product.n1) annotation(Line(visible = true, origin = {57.812, -6.25}, points = {{-16.562, 1.25}, {2.188, 1.25}, {2.188, -13.75}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(ubi.p1, enzyme.n1) annotation(Line(visible = true, origin = {10.25, 22}, points = {{31, -17}, {39.75, -17}, {39.75, 3}, {14.75, 3}, {-10.25, 3}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(substrate.n1, uui.s1) annotation(Line(visible = true, origin = {-38.5, -21.188}, points = {{-21.5, 1.188}, {-21.5, 1.188}, {10.891, 1.188}, {27.25, 1.188}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  connect(uui.p1, product.n1) annotation(Line(visible = true, origin = {44.818, -20.514}, points = {{-33.568, 0.514}, {-17.899, 0.514}, {10.182, 0.514}, {15.182, 0.514}}, color = {26, 118, 164}, smooth = Smooth.Bezier));
  annotation(preferredView = "info", uses(Modelica(version = "4.0.0"), BioChem(version = "2.0")), experiment(StopTime = 60, __Wolfram_SynchronizeWithRealTime = false), __Wolfram(ControlPanels(Panel(identifier = "vigilant-lovelace", title = "Model parameters", elements = {InputField(variable = Ec0, label = "Initial concentration of enzymes"), InputField(variable = Pc0, label = "Initial concentration of product"), InputField(variable = Sc0, label = "Initial concentration of substrate"), InputField(variable = V, label = "Compartment volume (constant)"), InputField(variable = kCat, label = "Reaction rate coefficient for enzyme reaction (1/s)"), InputField(variable = kOff, label = "Disassociation coefficient for enzyme-substrate binding reaction (1/s)"), InputField(variable = kOn, label = "Association coefficient for enzyme-substrate binding reaction")}))), Documentation(info = "<html>
<div style=\"background-color: #f4fbff; padding: 1rem; border: 2px solid #d9e5f3\">
<h2>Library Dependency</h2>
    <p class=\"\">
		This model requires the <a href=\"https://www.wolfram.com/system-modeler/libraries/biochem/\">BioChem</a> library.
	</p>
	<ul>
		<li style=\"background: url('modelica://EducationExamples/Resources/BioChem.png') no-repeat left top; background-size: 32px 32px; padding-left: 40px;\">The free BioChem library is an extendable, general purpose Modelica library for modeling, simulation and visualization of biological and biochemical systems. The library is designed to be used together with Wolfram System Modeler, which enables several extra features such as Systems Biology Markup Language (SBML) import and export. BioChem can, for instance, be used for selecting drug targets with PK/PD modeling or searching for novel drug targets with mechanistic modeling of the reactions in a cell or organism.</li>

	</ul>

</div>
    <h4>Model</h4>

    <p>
This model illustrates a standard enzyme reaction, together with a non-enzymatic, alternative reaction path. Most enzymes are proteins, and they increase the rate of reactions in organisms by lowering the activation energy required for the reaction. Without enzymes, some processes in the human body would take days, some even decades. Defective enzymes are linked to a number of different diseases and medical conditions such as lactose intolerance.
</p>
    <p>
The example model consists of a two-pathway reaction model, an enzymatic and a non-enzymatic reaction. The enzymatic reaction by default has a rate one million times higher than the non-enzymatic one.
</p>
    <h4>Simulation</h4>
    <p>
Simulating the model will make it possible to see how the enzyme concentration affects the reaction rate.
</p>
<p style=\"text-align: center;\"><img src=\"modelica://EnzymeCatalysis/DocumentationFiles/concentrations01.png\" style=\"width:600px\" alt=\"\" /></p>
<p>Simulate the model by clicking the Simulate button: <img src=\"modelica://EnzymeCatalysis/DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"\" /></p>

<p>
If you want to see how a change in enzyme concentration, rate constant or anything else would affect the model, this is possible. To change the initial conditions, you can edit the values of <span>Sc0</span>, <span>Pc0</span> and <span>Ec0</span> n the <span>Parameters</span> tab to change the initial substrate, product or enzyme concentration. Modify the corresponding initial concentration or parameter that you would like to change and then click the <span>Simulate</span> button again.
</p>
    <h4>Advanced</h4>
    <p>
In the model, you can change how the enzyme complex is initialized. The default behavior is to initialize the enzyme complex with zero concentration. This corresponds to a situation were the enzyme and subtrate are quickly mixed together. By changing the <span>enzymeInitialization</span> parameter, you can force the concentrations to instead initialize in steady-state.
</p>
<p style=\"text-align: center;\"><img src=\"modelica://EnzymeCatalysis/DocumentationFiles/steadystatecomparison01.png\" style=\"width:600px\" alt=\"\" /></p>
<p>In order to get the full experience of this example, you need a desktop Wolfram Language product. A free trial download is available at <a href=\"https://www.wolfram.com/mathematica/trial/\">www.wolfram.com/mathematica/trial/</a></p>
<p>For the full example, open the accompanying notebook <a href=\"EnzymeCatalysis.nb\">EnzymeCatalysis.nb</a>.</p>

</html>", figures = {Figure(title = "Concentrations", identifier = "f6d24", preferred = true, plots = {Plot(curves = {Curve(y = substrate.c, legend = "Substrate"), Curve(y = product.c, legend = "Product")}), Plot(curves = {Curve(y = enzyme.c, legend = "Enzyme"), Curve(y = ES_complex.c, legend = "Enzyme Complex")})}), Figure(title = "Substrate and product concentrations", identifier = "48186", plots = {Plot(curves = {Curve(y = substrate.c, legend = "Substrate"), Curve(y = product.c, legend = "Product")})}), Figure(title = "Enzyme complex concentrations", identifier = "a295a", plots = {Plot(curves = {Curve(y = enzyme.c, legend = "Enzyme"), Curve(y = ES_complex.c, legend = "Enzyme Complex")})}), Figure(title = "Reaction rates", identifier = "ded14", plots = {Plot(curves = {Curve(y = bur.rr, legend = "Enzyme-Substrate Binding"), Curve(y = ubi.rr, legend = "Enzyme Reaction"), Curve(y = uui.rr, legend = "Uncatalyzed Reaction")})})}), Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {119, 163, 37}, fillColor = {242, 224, 152}, fillPattern = FillPattern.Solid, lineThickness = 4, extent = {{-110, -110}, {110, 110}}, radius = 20), Text(visible = mainCompartment, origin = {1.438, -5}, extent = {{-111.438, -45}, {108.562, 45}}, textString = "main", fontName = "Arial"), Rectangle(visible = true, origin = {3.188, 0}, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-113.188, -113.188}, {113.188, 113.188}}, radius = 25), Text(visible = true, origin = {17.682, 26.428}, textColor = {255, 255, 255}, extent = {{-124.457, -86.428}, {95.173, 35.589}}, textString = "Ex", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-80, -50}, {80, 50}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5})));
end EnzymeCatalysis;
